# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

import os
import re

BASE = os.path.dirname(os.path.realpath(__file__))
"""
Base directory
"""

IS_WINDOWS = os.name == 'nt'
"""
Boolean for whether the CLI is in the Windows env
"""

IO_DELIM = '(?<!\\\\),(?=[\w/.$]+)'
"""
Defines the IO delimiter for json key/value pairs on config set
"""

KEY_VALUE_SPLIT = '(?<!\\\\)(?<!=)=(?!=)'
"""
Defines the key/value delimiter
"""

PLATFORM_WINDOWS = 'windows'
"""
Defines the Windows platform system name.
"""

AZDATA_USERNAME = 'AZDATA_USERNAME'
"""
Defines the username env variable for login
"""

AZDATA_PASSWORD = 'AZDATA_PASSWORD'
"""
Defines the password env variable for login
"""

WHEEL_INFO_RE = re.compile(
    r"""^(?P<namever>(?P<name>.+?)(-(?P<ver>\d.+?))?)
    ((-(?P<build>\d.*?))?-(?P<pyver>.+?)-(?P<abi>.+?)-(?P<plat>.+?)
    \.whl|\.dist-info)$""",
    re.VERBOSE).match
"""
Tokenize a Python wheel's filename.

{distro-{version}(-{build-tag})?-{python-tag}-{abi tag}-{platform-tag}.whl

Example:

requests-9.0.1-py2.py3-none-any.whl 

The version 9.0.1 build of the requests package is compatible with both Python 2 
and 3, and has no Application Binary Interface (pure Python), and is compatible 
with any CPU architecture.
"""
